@@ -305,7 +305,7 @@ class Lexer(object):
 
     def match_comment(self):
         """matches the multiline version of a comment"""
-        match = self.match(r"<%doc>(.*)</%doc>", re.S)
+        match = self.match(r"<%doc>(.*?)</%doc>", re.S)
         if match:
             self.append_node(parsetree.Comment, match.group(1))
             return True
