@@ -16,7 +16,7 @@ import imp, time, weakref, tempfile, shutil,  os, stat, sys, re
     
 class Template(object):
     """a compiled template"""
-    def __init__(self, text=None, filename=None, uri=None, format_exceptions=False, error_handler=None, lookup=None, output_encoding=None, module_directory=None, cache_type=None, cache_dir=None, module_filename=None, input_encoding=None, default_filters=['unicode'], imports=None, preprocessor=None):
+    def __init__(self, text=None, filename=None, uri=None, format_exceptions=False, error_handler=None, lookup=None, output_encoding=None, module_directory=None, cache_type=None, cache_dir=None, cache_url=None, module_filename=None, input_encoding=None, default_filters=['unicode'], buffer_filters=[], imports=None, preprocessor=None):
         """construct a new Template instance using either literal template text, or a previously loaded template module
         
         text - textual template source, or None if a module is to be provided
@@ -39,6 +39,7 @@ class Template(object):
             self.uri = self.module_id
         
         self.default_filters = default_filters
+        self.buffer_filters = buffer_filters
         self.input_encoding = input_encoding
         self.imports = imports
         self.preprocessor = preprocessor
@@ -92,6 +93,7 @@ class Template(object):
         self.output_encoding = output_encoding
         self.cache_type = cache_type
         self.cache_dir = cache_dir
+        self.cache_url = cache_url
 
     source = property(lambda self:_get_module_info_from_callable(self.callable_).source, doc="""return the template source code for this Template.""")
     code = property(lambda self:_get_module_info_from_callable(self.callable_).code, doc="""return the module source code for this Template""")
@@ -128,6 +130,7 @@ class DefTemplate(Template):
         self.parent = parent
         self.callable_ = callable_
         self.default_filters = parent.default_filters
+        self.buffer_filters = parent.buffer_filters
         self.input_encoding = parent.input_encoding
         self.imports = parent.imports
         self.output_encoding = parent.output_encoding
@@ -138,6 +141,7 @@ class DefTemplate(Template):
         self.filename = parent.filename
         self.cache_type = parent.cache_type
         self.cache_dir = parent.cache_dir
+        self.cache_url = parent.cache_url
 
     def get_def(self, name):
         return self.parent.get_def(name)
@@ -173,7 +177,7 @@ class ModuleInfo(object):
 def _compile_text(template, text, filename):
     identifier = template.module_id
     node = Lexer(text, filename, input_encoding=template.input_encoding, preprocessor=template.preprocessor).parse()
-    source = codegen.compile(node, template.uri, filename, default_filters=template.default_filters, imports=template.imports)
+    source = codegen.compile(node, template.uri, filename, default_filters=template.default_filters, buffer_filters=template.buffer_filters, imports=template.imports)
     cid = identifier
     module = imp.new_module(cid)
     code = compile(source, cid, 'exec')
@@ -184,7 +188,7 @@ def _compile_module_file(template, text, filename, outputpath):
     identifier = template.module_id
     (dest, name) = tempfile.mkstemp()
     node = Lexer(text, filename, input_encoding=template.input_encoding, preprocessor=template.preprocessor).parse()
-    source = codegen.compile(node, template.uri, filename, default_filters=template.default_filters, imports=template.imports)
+    source = codegen.compile(node, template.uri, filename, default_filters=template.default_filters, buffer_filters=template.buffer_filters, imports=template.imports)
     os.write(dest, source)
     os.close(dest)
     shutil.move(name, outputpath)
